defmodule Chronoscope.NTS.Behaviour do
  @callback(key_establishment(host :: String.t(), port :: integer()) :: {:ok, Map.t()}, {:error, any()})
end

defmodule Chronoscope.NTS do
  @behaviour Chronoscope.NTS.Behaviour

  require Logger

  alias Chronoscope.NTS

  def healthy?() do
    true
  end

  def list() do
    DynamicSupervisor.count_children(Chronoscope.DynamicSupervisor)
    |> IO.inspect()
  end

  def key_establishment(host, port) do
    # todo don't use atoms for this
    name = String.to_atom("#{host}#{port}")

    if GenServer.whereis(name) == nil do
      DynamicSupervisor.start_child(Chronoscope.DynamicSupervisor, {NTS.Client, name: name})
    end

    GenServer.call(name, {:key_establishment, %{host: host, port: port}})
  end
end
